ik-llama-cpp-sys 0.1.1

Low level bindings to ik_llama.cpp (ikawrakow's SOTA-quant fork)
docs.rs failed to build ik-llama-cpp-sys-0.1.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: ik-llama-cpp-sys-0.1.5

Low-level FFI bindings to ik_llama.cpp (ikawrakow's SOTA-quant fork of llama.cpp).

The bindings are generated by bindgen in build.rs against the vendored ik_llama.cpp/include/llama.h + ggml/include/gguf.h and included below.